@@ -85,6 +85,57 @@ func TestAppendSliceToASliceOfSlices(t *testing.T) {
 {{ $obj = $obj | append (slice "b") }}
 {{ $obj = $obj | append (slice "c") }}
 
+{{ $obj }}
+
+  `
+
+	b := hugolib.NewIntegrationTestBuilder(
+		hugolib.IntegrationTestConfig{
+			T:           t,
+			TxtarString: files,
+		},
+	).Build()
+
+	b.AssertFileContent("public/index.html", "[[a] [b] [c]]")
+
+}
+
+func TestAppendNilToSlice(t *testing.T) {
+
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+-- layouts/index.html --
+{{ $obj := (slice "a") }}
+{{ $obj = $obj | append nil }}
+
+{{ $obj }}
+
+
+  `
+
+	b := hugolib.NewIntegrationTestBuilder(
+		hugolib.IntegrationTestConfig{
+			T:           t,
+			TxtarString: files,
+		},
+	).Build()
+
+	b.AssertFileContent("public/index.html", "[a &lt;nil&gt;]")
+
+}
+
+func TestAppendNilsToSliceWithNils(t *testing.T) {
+
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+-- layouts/index.html --
+{{ $obj := (slice "a" nil "c") }}
+{{ $obj = $obj | append nil }}
+
 {{ $obj }}
 
 
@@ -99,7 +150,7 @@ func TestAppendSliceToASliceOfSlices(t *testing.T) {
 			},
 		).Build()
 
-		b.AssertFileContent("public/index.html", "[[a] [b] [c]]")
+		b.AssertFileContent("public/index.html", "[a &lt;nil&gt; c &lt;nil&gt;]")
 
 	}
 
